# dmbiolib

Library of Python functions for bioinformatics

Install from Bioconda:
````
conda install -c bioconda dmbiolib
````
Install from PyPI:
````
pip install dmbiolib
````
Full documentation: https://dmbiolib.readthedocs.io/

GitHub issues (bug reports, feature requests): https://github.com/damienmarsic/dmbiolib/issues/new/choose

[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/dmbiolib/README.html)

[![dmbiolib documentation](https://img.shields.io/badge/dmbiolib-Documentation-yellow)](https://dmbiolib.readthedocs.io/)


